// CMenu.cpp
// by Comanche

#include "CMenu.h"
#include "CMain.h"
#include "CLog.h"
#include "CButton.h"
#include "CGraphics.h"
#include "CLandScape.h"
#include "CTexture.h"
#include "CViewport.h"
#include "CLiquid.h"

extern CMain GameMain;
extern CLog Log;
extern CGraphics Graphics;
extern CLandScape Land;
extern CViewport *Viewports[4];
extern CTexture *Textures[1024];

//////////////////////////////////////////////////////////////////////////////////
//							main menu functions									//
//////////////////////////////////////////////////////////////////////////////////

BOOL CMenu::Menu()
{
	Exit=FALSE;
	Open=TRUE;

	MenuButtons[1] = new CButton(101,62,198,82,"Editor >","");
	MenuButtons[2] = new CButton(101,20,198,40,"File >","");
	MenuButtons[3] = new CButton(101,41,198,61,"Terrain >","");

	while(!GameMain.MouseB[0] && !Exit)
	{
		GameMain.GetMouseInfo();
		GameMain.GetKeyboardInfo();

		if(MenuButtons[1]->TestIfPressed())
		{
			Editor();
			continue;
		}
		if(MenuButtons[2]->TestIfPressed() && GameMain.Editor==0) 
		{
			File();	
			continue;
		}
		if(MenuButtons[3]->TestIfPressed() && GameMain.Editor==0) 
		{
			TextureOps();
			continue;
		}
		if(GameMain.KeyboardB[0]=='E')
		{
			MenuButtons[1]->RedrawPushedButton();
			Editor();
			continue;
		}
		if(GameMain.KeyboardB[0]=='F' && GameMain.Editor==0)
		{
			MenuButtons[2]->RedrawPushedButton();
			File();
			continue;
		}
		if(GameMain.KeyboardB[0]=='T' && GameMain.Editor==0)
		{
			MenuButtons[3]->RedrawPushedButton();
			TextureOps();
			continue;
		}
		if(GameMain.KeyboardB[0]==27)
			break;

		Graphics.BltToBackBuffer();
		Graphics.GetDC();
		DrawIcon(Graphics.xdc,GameMain.MouseX,GameMain.MouseY,GameMain.Cursor);
		Graphics.ReleaseDC();
		Graphics.Flip();
	}

	if(GameMain.Editor==0) 
	{
		Graphics.Lock();
		Land.FillScreen(101,20,297,104);
		Graphics.UnLock();
	}
	if(GameMain.Editor==1) 
	{
		Graphics.Lock();
		Graphics.DrawButton(101,0,369,239);
		Graphics.UnLock();
		Viewports[0]->RedrawViewport();
	}
	
	delete MenuButtons[1];
	delete MenuButtons[2];
	delete MenuButtons[3];

	Open=FALSE;
	return(TRUE);
}

//////////////////////////////////////////////////////////////////////////////////

BOOL CMenu::File()
{
	MenuButtons[4] = new CButton(199,20,297,40,"Save File","");
	MenuButtons[5] = new CButton(199,41,297,61,"Load File","");

	while(!GameMain.MouseB[0] && !Exit)
	{
		GameMain.GetMouseInfo();
		GameMain.GetKeyboardInfo();
		if(GameMain.KeyboardB[0]==27)
			break;
		if(GameMain.KeyboardB[0]=='S') SaveMap();
		if(GameMain.KeyboardB[0]=='L') LoadMap();
		if(MenuButtons[4]->TestIfPressed()) SaveMap();
		if(MenuButtons[5]->TestIfPressed()) LoadMap();
		Graphics.BltToBackBuffer();
		Graphics.GetDC();
		DrawIcon(Graphics.xdc,GameMain.MouseX,GameMain.MouseY,GameMain.Cursor);
		Graphics.ReleaseDC();
		Graphics.Flip();
	}	

	delete MenuButtons[4];
	delete MenuButtons[5];	
	return(TRUE);
}

//////////////////////////////////////////////////////////////////////////////////

BOOL CMenu::TextureOps()
{
	MenuButtons[4] = new CButton(199,41,297,61,"Fill Land 32","");
	MenuButtons[5] = new CButton(199,62,297,82,"Fill Land 16","");
	MenuButtons[6] = new CButton(199,83,297,104,"Fill Land 0","");
	
	while(!GameMain.MouseB[0] && !Exit)
	{
		GameMain.GetMouseInfo();
		GameMain.GetKeyboardInfo();
		if(GameMain.KeyboardB[0]==27)
			break;
		if(MenuButtons[4]->TestIfPressed()) FillLand(32);
		if(MenuButtons[5]->TestIfPressed()) FillLand(16);
		if(MenuButtons[6]->TestIfPressed()) FillLand(0);
		Graphics.BltToBackBuffer();
		Graphics.GetDC();
		DrawIcon(Graphics.xdc,GameMain.MouseX,GameMain.MouseY,GameMain.Cursor);
		Graphics.ReleaseDC();
		Graphics.Flip();
	}	

	delete MenuButtons[4];
	delete MenuButtons[5];
	delete MenuButtons[6];
	return(TRUE);
}

//////////////////////////////////////////////////////////////////////////////////

BOOL CMenu::Editor()
{
	MenuButtons[4] = new CButton(199,62,297,82,"Land","");
	MenuButtons[5] = new CButton(199,83,297,103,"Voxel","");

	while(!GameMain.MouseB[0] && !Exit)
	{
		GameMain.GetMouseInfo();
		GameMain.GetKeyboardInfo();
		if(GameMain.KeyboardB[0]==27)
			break;
		if(MenuButtons[4]->TestIfPressed()) SetEditor(0);
		if(MenuButtons[5]->TestIfPressed()) SetEditor(1);
		if(GameMain.KeyboardB[0]=='L') SetEditor(0);
		if(GameMain.KeyboardB[0]=='V') SetEditor(1);
		Graphics.BltToBackBuffer();
		Graphics.GetDC();
		DrawIcon(Graphics.xdc,GameMain.MouseX,GameMain.MouseY,GameMain.Cursor);
		Graphics.ReleaseDC();
		Graphics.Flip();
	}

	delete MenuButtons[4];
	delete MenuButtons[5];

	return(TRUE);
}

//////////////////////////////////////////////////////////////////////////////////

BOOL CMenu::FillLand(int height)
{
	Exit=TRUE;

	if(Selection==-1) return(TRUE);

	int x,x2,y,y2;
	RGBTRIPLE color;
	BYTE red,green,blue;
	DWORD buffer2;
	int Pos=ScrolPos+Selection;
	int percent;

	if(Textures[Pos]->isfailure) return(TRUE);

	for(int i=0;i<2000;i++)
	{
		for(int i2=0;i2<2000;i2++)
		{
		x=i/Textures[Pos]->width;
		y=i2/Textures[Pos]->height;
		x2=i-(x*Textures[Pos]->width);
		y2=i2-(y*Textures[Pos]->height);

		color=Textures[Pos]->GetPixel(x2,y2);
		red=color.rgbtRed; green=color.rgbtGreen; blue=color.rgbtBlue;
		buffer2=(((height)<<24)|((red)<<16)|((green)<<8)|(blue));
		Land.Landscape[i][i2]=buffer2;	
		}
	}

	Land.InitScreen();
	CreateMiniMap();
	DrawMiniMap();

	return(TRUE);
}

//////////////////////////////////////////////////////////////////////////////////

BOOL CMenu::SetEditor(int editor)
{
	Exit=TRUE;

	if(editor==GameMain.Editor) return(TRUE);

	GameMain.Editor=editor;
	GameMain.GameRestart();

	return(TRUE);
}

//////////////////////////////////////////////////////////////////////////////////
//							MiniMap functions									//
//////////////////////////////////////////////////////////////////////////////////

void CMenu::CreateMiniMap()
{
	int red=0,green=0,blue=0;
	int counter=0;
	BYTE *pointer;

	for(BYTE x=0;x<64;x++)
		for(BYTE y=0;y<64;y++)
		{
		counter=0;
		red=0;green=0;blue=0;
		for(int i=0;i<32;i++)
			for(int i2=0;i2<32;i2++)
			{
				counter++;
				pointer=(BYTE*)&Land.Landscape[x+i][y+i2];
				blue+=*pointer;
				green+=*(++pointer);
				red+=*(++pointer);
			}
		MiniMapR[x][y]=red/counter;
		MiniMapG[x][y]=green/counter;
		MiniMapB[x][y]=blue/counter;	
	}
}

//////////////////////////////////////////////////////////////////////////////////

void CMenu::DrawMiniMap()
{
	for(int x=0;x<64;x++)
		for(int y=0;y<64;y++)
		{
			Graphics.Lock();
			Graphics.PutPixel(17+x,y+271,
							  MiniMapR[x][y],
							  MiniMapG[x][y],
							  MiniMapB[x][y]);
			Graphics.UnLock();
		}
}

//////////////////////////////////////////////////////////////////////////////////
//						texture menu funktions									//
//////////////////////////////////////////////////////////////////////////////////


void CMenu::DrawTextures()
{
	int red=0,green=0,blue=0;	
	RGBTRIPLE color;
	int colord=0;
	int counter=0;
	
	Graphics.logfont.lfHeight = TEXTUREFONTHEIGHT;	
	Graphics.textcolor.rgbtRed = 192;
	Graphics.textcolor.rgbtGreen = 192;
	Graphics.textcolor.rgbtBlue = 192;	

	for(int i=0;i<7;i++)	
	{

		int TexPos=i+ScrolPos;
		int PosX=573;
		int PosY=9+(65*i);

		Graphics.BlackQuader(PosX,PosY,PosX+64,PosY+64);
		

		Graphics.Lock();
		if(!Textures[TexPos]) continue;		
		if(Textures[TexPos]->isfailure) continue;

			if(Textures[TexPos]->width<=64 && Textures[TexPos]->height<=64)
			{

				for(int x=0;x<Textures[TexPos]->width;x++)
					for(int y=0;y<Textures[TexPos]->height;y++)
				{
				color=Textures[TexPos]->GetPixel(x,y);
				Graphics.PutPixel(PosX+x,PosY+y,color.rgbtRed,
								  color.rgbtGreen,color.rgbtBlue);		
				}
			}

			else
			{
				int scale=0;

				if(Textures[TexPos]->width>Textures[TexPos]->height)
					scale=Textures[TexPos]->width/64;
				else scale=Textures[TexPos]->height/64;

				for(int x=0;x<Textures[TexPos]->width;x++)
					for(int y=0;y<Textures[TexPos]->height;y++)
				{
					counter=0;
					red=0;green=0;blue=0;
					for(int i=0;i<scale;i++)
						for(int i2=0;i2<scale;i2++)
					{
						if(Textures[TexPos]->width>(x+i) &&
						   Textures[TexPos]->height>(y+i2))
						{
						counter++;
						color=Textures[TexPos]->GetPixel(x+i,y+i2);
						red=red+color.rgbtRed;
						green=green+color.rgbtGreen;
						blue=blue=blue+color.rgbtBlue;
						}
					}
					red=red/counter;
					green=green/counter;
					blue=blue/counter;

					Graphics.PutPixel(PosX+x/scale,PosY+y/scale,red,green,blue);

				}
			}

		Graphics.UnLock();

		Graphics.OSGetLaDC();
		Graphics.Text(PosX+2,PosY+2,Textures[TexPos]->Name);
		Graphics.OSReleaseDC();

	} // end for

	Graphics.textcolor.rgbtRed = 0;
	Graphics.textcolor.rgbtGreen = 0;
	Graphics.textcolor.rgbtBlue = 0;
	Graphics.logfont.lfHeight = STANDARTFONTHEIGHT;
}

//////////////////////////////////////////////////////////////////////////////////
//						file menu functions									//
//////////////////////////////////////////////////////////////////////////////////

void CMenu::SaveMap()
{
	while(GameMain.KeyboardB[0])
		GameMain.GetKeyboardInfo();

	int mfh;
	OFSTRUCT map_file_data;

	Exit=TRUE;

	Graphics.Lock();
	Land.FillScreen(101,20,297,82);
	Graphics.DrawButton(101,450,559,479);
	Graphics.DrawPushedButton(110,455,550,475);
	Graphics.UnLock();

	int i=0;
	
	GameMain.GetKeyboardInfo();
	sprintf(buffer,"");

	while(GameMain.KeyboardB[0]!=13)
	{
		GameMain.GetKeyboardInfo();

		if(GameMain.KeyboardB[0]==8)
		{
			if(i==0) continue;
			buffer[i-1]=0;
			i--;
			while(GameMain.KeyboardB[0])
				GameMain.GetKeyboardInfo();
		}
	
		if(GameMain.KeyboardB[0]==27)
		{
			Graphics.Lock();
			Land.FillScreen(101,450,559,479);	
			Graphics.UnLock();
			return;
		}

		if(GameMain.KeyboardB[0]!=0)
		{
			if(i>20) continue;
			if(GameMain.KeyboardB[0]==27) continue;
			if(GameMain.KeyboardB[0]==8) continue;
			buffer[i]=GameMain.KeyboardB[0];
			buffer[i+1]=0;
			i++;
			while(GameMain.KeyboardB[0])
				GameMain.GetKeyboardInfo();
		}

	
		GameMain.GetMouseInfo();
		Graphics.BltToBackBuffer();
		Graphics.GetLaDC();
		Graphics.Text(114,458,buffer);
		DrawIcon(Graphics.xdc,GameMain.MouseX,GameMain.MouseY,GameMain.Cursor);		
		Graphics.ReleaseDC();
		Graphics.Flip();

		GameMain.GetKeyboardInfo();
	}

	Graphics.Lock();
	Land.FillScreen(101,450,559,479);	
	Graphics.UnLock();
	Graphics.BltToBackBuffer();
	Graphics.GetDC();
	DrawIcon(Graphics.xdc,GameMain.MouseX,GameMain.MouseY,GameMain.Clock);		
	Graphics.ReleaseDC();
	Graphics.Flip();

	if(!buffer[0]) return;

	char filename[80];
	sprintf(filename,"MAPS\\%s.VMP",buffer);
	mfh = OpenFile(filename,&map_file_data,OF_CREATE);

	if(mfh == HFILE_ERROR)
	{
		sprintf(buffer,"> Error: Saving %s",filename);
		Log.WriteErrorToLogFile(buffer);
		return;
	}
	
	_lwrite(mfh,"PEVoxEd Map 1.1",strlen("PEVoxEd Map 1.0"));

	_lwrite(mfh,(CHAR *)&Land.Day,sizeof(BOOL));

	_lwrite(mfh,(CHAR *)&Land.Landscape,sizeof(Land.Landscape));

	_close(mfh);

	sprintf(buffer,"> Saved File: %s",filename);
	Log.WriteToLogFile(buffer);

	sprintf(buffer,"");
}

//////////////////////////////////////////////////////////////////////////////////

void CMenu::LoadMap()
{
	while(GameMain.KeyboardB[0])
		GameMain.GetKeyboardInfo();

	int mfh;
	OFSTRUCT map_file_data;

	BOOL Cursor=TRUE;
	char buffer2[80];

	Exit=TRUE;

	Graphics.Lock();
	Land.FillScreen(101,20,297,82);
	Graphics.DrawButton(101,450,559,479);
	Graphics.DrawPushedButton(110,455,550,475);
	Graphics.UnLock();

	int i=0;
	
	GameMain.GetKeyboardInfo();
	sprintf(buffer,"");

	while(GameMain.KeyboardB[0]!=13)
	{
		GameMain.GetKeyboardInfo();

		if(GameMain.KeyboardB[0]==8)
		{
			if(i==0) continue;
			buffer[i-1]=0;
			i--;
			while(GameMain.KeyboardB[0])
				GameMain.GetKeyboardInfo();
		}

		if(GameMain.KeyboardB[0]==27)
		{
			Graphics.Lock();
			Land.FillScreen(101,450,559,479);	
			Graphics.UnLock();
			return;
		}
	
		if(GameMain.KeyboardB[0]!=0)
		{
			if(i>20) continue;
			if(GameMain.KeyboardB[0]==27) continue;
			if(GameMain.KeyboardB[0]==8) continue;
			buffer[i]=GameMain.KeyboardB[0];
			buffer[i+1]=0;
			i++;
			while(GameMain.KeyboardB[0])
				GameMain.GetKeyboardInfo();
		}

		GameMain.GetMouseInfo();
		Graphics.BltToBackBuffer();
		Graphics.GetLaDC();
		Graphics.Text(114,458,buffer);
		DrawIcon(Graphics.xdc,GameMain.MouseX,GameMain.MouseY,GameMain.Cursor);		
		Graphics.ReleaseDC();
		Graphics.Flip();

		GameMain.GetKeyboardInfo();
	}

	if(!buffer[0]) 
	{
		Graphics.Lock();
		Land.FillScreen(101,450,559,479);	
		Graphics.UnLock();
		return;
	}

	Graphics.Lock();
	Land.FillScreen(101,450,559,479);	
	Graphics.UnLock();
	Graphics.BltToBackBuffer();
	Graphics.GetDC();
	DrawIcon(Graphics.xdc,GameMain.MouseX,GameMain.MouseY,GameMain.Clock);		
	Graphics.ReleaseDC();
	Graphics.Flip();
	

	char filename[80];
	sprintf(filename,"MAPS\\%s.VMP",buffer);
	mfh = OpenFile(filename,&map_file_data,OF_READ);
	
	if(mfh == HFILE_ERROR)
	{
		_close(mfh);
		sprintf(buffer,"> Error: Reading %s",filename);
		Log.WriteErrorToLogFile(buffer);
		Graphics.Lock();
		Land.FillScreen(101,450,559,479);	
		Graphics.UnLock();	
		
		MessageBox("Error","Can't read file",MS_OK);		

		return;
	}	

	ZeroMemory(buffer,sizeof(buffer));

	_lread(mfh,(LPVOID)buffer,strlen("PEVoxEd Map 1.0"));
	
	if(strcmp(buffer,"PEVoxEd Map 1.0")==0)
	{
		Land.Day=TRUE;

		_lread(mfh,&Land.Landscape,sizeof(Land.Landscape));

		_close(mfh);

		sprintf(buffer,"> Loaded File: %s",filename);
		Log.WriteToLogFile(buffer);
	}
	else if(strcmp(buffer,"PEVoxEd Map 1.1")==0)
	{
		if(_lread(mfh,&Land.Day,sizeof(BOOL))==HFILE_ERROR)
			Log.WriteErrorToLogFile("> Error");

		if(_lread(mfh,&Land.Landscape,sizeof(Land.Landscape))==HFILE_ERROR)
			Log.WriteErrorToLogFile("> Error");			

		_close(mfh);

		sprintf(buffer,"> Loaded File: %s",filename);
		Log.WriteToLogFile(buffer);
	}
	else
	{
		_close(mfh);
		sprintf(buffer,"> %s: Not a PEVoxEd Map",filename);
		Log.WriteErrorToLogFile(buffer);

		MessageBox("Error","Can't read file",MS_OK);

		return;
	}

	Graphics.Lock();
	Land.InitScreen();
	CreateMiniMap();
	DrawMiniMap();		
	Graphics.UnLock();
}

//////////////////////////////////////////////////////////////////////////////////

void CMenu::DrawTextures(int TexPos)
{
	int red=0,green=0,blue=0;	
	RGBTRIPLE color;
	int colord=0;
	int counter=0;
	
	Graphics.logfont.lfHeight = TEXTUREFONTHEIGHT;
	Graphics.textcolor.rgbtRed = 192;
	Graphics.textcolor.rgbtGreen = 192;
	Graphics.textcolor.rgbtBlue = 192;

	int PosX=573;
	int PosY=9+(65*TexPos);
	TexPos=TexPos+ScrolPos;

	Graphics.BlackQuader(PosX,PosY,PosX+64,PosY+64);

	Graphics.Lock();	
	if(!Textures[TexPos]) return;			
	if(Textures[TexPos]->isfailure) return;

	if(Textures[TexPos]->width<=64 && Textures[TexPos]->height<=64)
	{
		for(int x=0;x<Textures[TexPos]->width;x++)
			for(int y=0;y<Textures[TexPos]->height;y++)
		{
		color=Textures[TexPos]->GetPixel(x,y);
		Graphics.PutPixel(PosX+x,PosY+y,color.rgbtRed,
						  color.rgbtGreen,color.rgbtBlue);
		}
	}

	else
	{
		int scale;
			if(Textures[TexPos]->width>Textures[TexPos]->height)
			scale=Textures[TexPos]->width/64;
		else scale=Textures[TexPos]->height/64;
		for(int x=0;x<Textures[TexPos]->width;x++)
			for(int y=0;y<Textures[TexPos]->height;y++)
		{
			counter=0;
			red=0;green=0;blue=0;
			for(int i=0;i<scale;i++)
				for(int i2=0;i2<scale;i2++)
			{
				if(Textures[TexPos]->width>(x+i) &&
				   Textures[TexPos]->height>(y+i2))
				{
				counter++;					
				color=Textures[TexPos]->GetPixel(x+i,y+i2);
				red=red+color.rgbtRed;
				green=green+color.rgbtGreen;
				blue=blue=blue+color.rgbtBlue;
				}
			}
			red=red/counter;
			green=green/counter;
			blue=blue/counter;
			Graphics.PutPixel(PosX+x/scale,PosY+y/scale,red,green,blue);
		}
	}
	Graphics.UnLock();

	Graphics.OSGetLaDC();
	Graphics.Text(PosX+2,PosY+2,Textures[TexPos]->Name);
	Graphics.OSReleaseDC();

	Graphics.textcolor.rgbtRed = 0;
	Graphics.textcolor.rgbtGreen = 0;
	Graphics.textcolor.rgbtBlue = 0;
	Graphics.logfont.lfHeight = STANDARTFONTHEIGHT;
} 

//////////////////////////////////////////////////////////////////////////////////

void CMenu::DrawSelected(int TexPos)
{
	int red=0,green=0,blue=0;	
	RGBTRIPLE color;
	int colord=0;
	int counter=0;
	
	Graphics.logfont.lfHeight = TEXTUREFONTHEIGHT;
	Graphics.textcolor.rgbtRed = 192;
	Graphics.textcolor.rgbtGreen = 192;
	Graphics.textcolor.rgbtBlue = 192;

	int PosX=573;
	int PosY=9+(65*TexPos);
	TexPos=TexPos+ScrolPos;

	Graphics.BlackQuader(PosX,PosY,PosX+64,PosY+64);
	
	Graphics.Lock();
	if(!Textures[TexPos]) return;			
	if(Textures[TexPos]->isfailure) return;

	if(Textures[TexPos]->width<=64 && Textures[TexPos]->height<=64)
	{
		for(int x=0;x<Textures[TexPos]->width;x++)
			for(int y=0;y<Textures[TexPos]->height;y++)
		{
		color=Textures[TexPos]->GetPixel(x,y);
		blue=color.rgbtBlue;
		if(blue>=205) blue=255;
		else blue+=50;
		Graphics.PutPixel(PosX+x,PosY+y,color.rgbtRed,
						  color.rgbtGreen,blue);
		}
	}

	else
	{
		int scale;
		if(Textures[TexPos]->width>Textures[TexPos]->height)
			scale=Textures[TexPos]->width/64;
		else scale=Textures[TexPos]->height/64;
			for(int x=0;x<Textures[TexPos]->width;x++)
			for(int y=0;y<Textures[TexPos]->height;y++)
		{
			counter=0;
			red=0;green=0;blue=0;
			for(int i=0;i<scale;i++)
				for(int i2=0;i2<scale;i2++)
			{
				if(Textures[TexPos]->width>(x+i) &&
				   Textures[TexPos]->height>(y+i2))
				{
				counter++;					
				color=Textures[TexPos]->GetPixel(x+i,y+i2);
				red=red+color.rgbtRed;
				green=green+color.rgbtGreen;
				blue=blue+color.rgbtBlue;
				}
			}
			red=red/counter;
			green=green/counter;
			blue=blue/counter;
			if(blue>=205) blue=255;
			else blue+=50;
			Graphics.PutPixel(PosX+x/scale,PosY+y/scale,red,green,blue);
		}
	}
	Graphics.UnLock();

	Graphics.OSGetLaDC();
	Graphics.Text(PosX+2,PosY+2,Textures[TexPos]->Name);
	Graphics.OSReleaseDC();

	Graphics.textcolor.rgbtRed = 0;
	Graphics.textcolor.rgbtGreen = 0;
	Graphics.textcolor.rgbtBlue = 0;
	Graphics.logfont.lfHeight = STANDARTFONTHEIGHT;
} 

//////////////////////////////////////////////////////////////////////////////////

void CMenu::SelectTexture()
{
	while(GameMain.MouseB[0])
		GameMain.GetMouseInfo();	
	int y=GameMain.MouseY-8;	
	y=y/65;	
//	if(y>=GameMain.NumTextures) return;
	if(Selection>=0)		
		DrawTextures(Selection);	
	Selection=y;
	DrawSelected(y);
}

//////////////////////////////////////////////////////////////////////////////////

void CMenu::ScrollUp()
{
	if(GameMain.NumTextures<8)
		return;
	if(ScrolPos==0)
		return;
	Selection=-1;
	if(ScrolPos!=1)
	{
		ScrolPos-=2;
		Graphics.Blt(573,9,637,334,0,130);
		DrawTextures(0);
		DrawTextures(1);
	}
	else 
	{
		ScrolPos-=1;
		Graphics.Blt(573,9,637,399,0,65);
		DrawTextures(0);
	}	
}

//////////////////////////////////////////////////////////////////////////////////

void CMenu::ScrollDown()
{
	if(GameMain.NumTextures<8)
		return;
	if(ScrolPos+8>GameMain.NumTextures)
		return;
	if(ScrolPos+8>1024)
		return;
	Selection=-1;
	if(ScrolPos+9>GameMain.NumTextures) 
	{
		ScrolPos+=1;
		Graphics.Blt(573,74,637,464,0,-65);
		DrawTextures(6);
	}
	else 
	{
		ScrolPos+=2;
		Graphics.Blt(573,139,637,464,0,-130);
		DrawTextures(5);
		DrawTextures(6);
	}
}

//////////////////////////////////////////////////////////////////////////////////
//						Message Box functions									//
//////////////////////////////////////////////////////////////////////////////////

BOOL CMenu::MessageBox(char *caption,char *string,int ms)
{
	Exit=FALSE;
	State=FALSE;
	
	BOOL Status7=FALSE;

	if(GameMain.Status2==7)
	{
		GameMain.Status2=1;
		Status7=TRUE;
	}

	while(GameMain.KeyboardB[0])
		GameMain.GetKeyboardInfo();

	if(!Graphics.StoreScreenArea(230,150,430,230)) return(FALSE);

	Graphics.Lock();
	Graphics.DrawButton(230,150,430,230);
	for(int i=0;i<98;i++)
	{
		Graphics.FullQuader(232+i*2,152,234+i*2,166,0,0,200-i);
	}
	Graphics.UnLock();

	Graphics.OSGetLaDC();
	Graphics.Text(234,151,caption);
	Graphics.OSReleaseDC();
	Graphics.OSGetDC();
	Graphics.Text(330,177,string);
	Graphics.OSReleaseDC();
	
	if(ms==MS_OK)
	{
		MenuButtons[0] = new CButton(290,200,370,220,"OK","");
	}
	if(ms==MS_YESNO)
	{
		MenuButtons[0] = new CButton(260,200,320,220,"Yes","");
		MenuButtons[1] = new CButton(340,200,400,220,"No","");
	}

	while(!Exit)
	{
		GameMain.GetMouseInfo();
		GameMain.GetKeyboardInfo();

		if(GameMain.KeyboardB[0]==13) 
		{
			State=TRUE;
			Exit=TRUE;
		}
		if(ms==MS_OK)
			if(MenuButtons[0]->TestIfPressed()) Exit=TRUE;
		if(ms==MS_YESNO)
		{
			if(MenuButtons[0]->TestIfPressed()) 
			{
				State=TRUE;
				Exit=TRUE;
			}
			if(MenuButtons[1]->TestIfPressed())
			{
				State=FALSE;
				Exit=TRUE;
			}
		}
		Graphics.BltToBackBuffer();		
		Graphics.GetDC();
		DrawIcon(Graphics.xdc,GameMain.MouseX,GameMain.MouseY,GameMain.Cursor);
		Graphics.ReleaseDC();
		Graphics.Flip();
	}

	if(ms==MS_OK)
	{
		delete MenuButtons[0];
	}
	if(ms==MS_YESNO)
	{
		delete MenuButtons[0];
		delete MenuButtons[1];
	}

	if(!Graphics.RestoreScreenArea()) return(FALSE);
	
	if(Status7==TRUE)
	{
		GameMain.Status2=7;
	}

	return(State);
}
